@@ -1,6 +1,8 @@
 describe.poisson.survey<-function(){
 category <- "count"
 description  <- "Survey-Weighted Poisson Regression for Event Count Dependent Variables"
+authors <- c("Nicholas Carnes")
+year <- 2008
 package <-list(	name 	="survey",
 		version	="3.6-13"
 		)
@@ -11,5 +13,5 @@ parameters$lambda<-list(equations=c(1,1),
 			expVar=TRUE
 			)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
