@@ -1,5 +1,5 @@
 qi.vglm <- function (object, simpar, x, x1=NULL, y = NULL) {
-  model <- object$zelig
+  model <- getzelig(object)
   cm <- object@constraints
   if (model=="mlogit")
     ndim <- (ncol(object@y)-1)
@@ -43,12 +43,12 @@ qi.vglm <- function (object, simpar, x, x1=NULL, y = NULL) {
     sim.eta <- NULL
     for (i in 1:ndim)
       sim.eta <- cbind(sim.eta, all.coef[[i]] %*% as.matrix(xm[[i]]))
-    ev <- object@family@inverse(sim.eta)
+    ev <- object@family@linkinv(sim.eta)
     colnames(ev) <- cnames
     ev
   }
   pr.vglm <- function(object, ev, ynames) { # To assign predicted values.
-    model <- object$zelig
+    model <- getzelig(object)
     if (model == "mlogit") {
       k <- ncol(ev)
       Ipr <- sim.cut <- matrix(NA, nrow = nrow(ev), ncol = ncol(ev))
