@@ -4,5 +4,7 @@ zelig2probit <- function(formula, model, data, M, ...) {
   mf$model <- FALSE
   mf[[1]] <- stats::glm
   mf$family <- binomial(link="probit")
+  if (is.character(mf$weights))
+    mf$weights <- as.name(mf$weights)
   as.call(mf)
 }
